@@ -1,5 +1,5 @@
 package Anki::Import ;
-$Anki::Import::VERSION = '0.008';
+$Anki::Import::VERSION = '0.009';
 use strict;
 use warnings;
 use Cwd;
@@ -7,6 +7,7 @@ use Path::Tiny;
 use Getopt::Args;
 use Log::Log4perl::Shortcuts qw(:all);
 use Exporter qw(import);
+use Data::Dumper qw(Dumper);
 our @EXPORT = qw(anki_import);
 
 # set up variables
@@ -17,29 +18,28 @@ my $cline      = '';      # current line
 my $lline;                # last (previous) line
 my %notes      = ();      # data structure for storing notes
 
+# process arguments
+arg parent_dir => (
+  isa => 'Str',
+  default => cwd,
+  comment => 'optional directory to save output files, default to current directory',
+);
+opt verbose => (
+  isa => 'Bool',
+  alias => 'v',
+  comment => 'provide details on progress of Anki::Import'
+);
+opt vverbose => (
+  isa => 'Bool',
+  alias => 'vv',
+  comment => 'verbose information plus debug info'
+);
+
 # start here
 sub anki_import {
   my $file = shift;
+  logf('No file passed to Anki::Import. Aborting.') if !$file;
 
-  # process arguments
-  arg parent_dir => (
-    isa => 'Str',
-    default => cwd,
-    comment => 'optional directory to save output files, default to current directory',
-  );
-  opt verbose => (
-    isa => 'Bool',
-    alias => 'v',
-    comment => 'provide details on progress of Anki::Import'
-  );
-  opt vverbose => (
-    isa => 'Bool',
-    alias => 'vv',
-    comment => 'verbose information plus debug info'
-  );
-  if (!@_) {
-    @_ = cwd;
-  }
   my $args = optargs( @_ );
 
   # set log level as appropriate
@@ -52,7 +52,6 @@ sub anki_import {
   }
   logi('Log level set');
 
-  logf('No file passed to Anki::Import. Aborting.') if !$file;
 
   # get and load the source file
   logi('Loading file');
@@ -268,7 +267,7 @@ Anki::Import - Anki note generation made easy.
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 OVERVIEW
 
@@ -302,6 +301,7 @@ etc.) so you can enter formatted notes into Anki's database more efficiently.
 =head2 Steps for creating, processing and imorting new notes
 
 =head3 Step 1: Generate the notes with your text editor
+
 First, you create a specially formatted source file which
 C<Anki::Import> will process. The source file is a simple text file with
 basic formatting rules you must follow.
@@ -309,6 +309,7 @@ basic formatting rules you must follow.
 See the L</General description of the source file> section for details.
 
 =head3 Step 2: Process the notes with C<Anki::Import>
+
 Once the source file is created and saved, run the
 C<anki_import> command from the command line or from a script to generate the
 import files. This will create a new directory called "anki_import_files"
@@ -319,6 +320,7 @@ created in the current directory.
 See the L</USAGE> section for more details and options.
 
 =head3 Step 3: Import the processed notes with Anki
+
 In Anki, open the deck you wish to import and hit Ctrl-I or (Cmd-I on a
 Mac) to start the import process, navigate to the a file generated by
 C<Anki::Import> and select one of them.
@@ -339,6 +341,7 @@ each source file should contain notes that will be imported into the same Anki
 deck.
 
 =head3 Creating notes and fields in the source file
+
 Each note in the source file contains fields which should correspond to your
 existing note types in Anki. Individual notes in the source file are delineated
 by two or more blank lines. Fields are separated by a
@@ -357,6 +360,7 @@ is likely the default encoding method for your editor but check your editor's
 settings and documentation for further details.
 
 =head3 Assigning notes to note types
+
 You can indicate which note type a note belongs to by preceding notes with a
 C<#note_type> comment at the beginning of a line. You can choose any note type
 name you wish but it is recommended that you use note type names similar to
@@ -375,7 +379,7 @@ note has the correct number of fields.
 Note: note type sections can be split across the file (i.e. you do not have to
 group the notes of a particular note type together).
 
-=head3 Applying text formatting ot your notes
+=head3 Applying text formatting to your notes
 
 Learning how to format the source file is key to getting Anki to import your
 notes properly and getting the most out of C<Anki::Import>.
@@ -504,6 +508,8 @@ See the L</Command line usage> for more details on the optional arguments.
 
 =item * L<Cwd|Cwd>
 
+=item * L<Data::Dumper|Data::Dumper>
+
 =item * L<Exporter|Exporter>
 
 =item * L<Getopt::Args|Getopt::Args>
